package handler

import (
	"github.com/gin-gonic/gin"
	"github.com/sirupsen/logrus"
	log "github.com/sirupsen/logrus"
	"youngee_m_api/consts"
	"youngee_m_api/db"
	"youngee_m_api/model/http_model"
	"youngee_m_api/service"
	"youngee_m_api/util"
)

func WrapCreateSubAccountHandler(ctx *gin.Context) {
	handler := newCreateSubAccountHandler(ctx)
	BaseRun(handler)
}

type CreateSubAccountHandler struct {
	ctx  *gin.Context
	req  *http_model.CreateSubAccountRequest
	resp *http_model.CommonResponse
}

func (c CreateSubAccountHandler) getContext() *gin.Context { return c.ctx }
func (c CreateSubAccountHandler) getResponse() interface{} { return c.resp }
func (c CreateSubAccountHandler) getRequest() interface{} {
	return c.req
}
func (c CreateSubAccountHandler) run() {
	data := http_model.CreateSubAccountRequest{}
	data = *c.req
	message, err := service.Register.AuthRegister(c.ctx, data.PhoneNumber, data.Code)
	if err != nil {
		// 数据库查询失败，redis失败
		logrus.Errorf("[CreateSubAccountHandler] call CreateSubAccount err:%+v\n", err)
		util.HandlerPackErrorResp(c.resp, consts.ErrorInternal, "")
		logrus.Info("CreateSubAccountHandler fail,req:%+v", c.req)
		return
	}
	if message == "" {
		res, Error := db.CreateSubAccount(c.ctx, &data)
		if Error != nil {
			logrus.Errorf("[RegisterHandler] call CreateEnterpriseUser err:%+v\n", err)
			util.HandlerPackErrorResp(c.resp, consts.ErrorInternal, "")
			log.Info("Register fail,req:%+v", c.req)
			return
		}
		c.resp.Message = "创建成功"
		// 4. 返回ok
		c.resp.Data = res
		c.resp.Status = consts.ErrorSuccess
	} else if message == "手机号已存在" {
		c.resp.Status = consts.ErrorInternal
	}

}
func (c CreateSubAccountHandler) checkParam() error {
	return nil
}

func newCreateSubAccountHandler(ctx *gin.Context) *CreateSubAccountHandler {
	return &CreateSubAccountHandler{
		ctx:  ctx,
		req:  http_model.NewCreateSubAccountRequest(),
		resp: http_model.NewCreateSubAccountResponse(),
	}
}
